/* Written by Doug Heisterkamp,  drh@cse.unl.edu
   Last modified: 11/12/96
*/
#include"Python.h"
#include"arrayobject.h"
#include "callback.h"

typedef struct { float r, i; } f2c_complex;
typedef struct { double r, i; } f2c_doublecomplex;
typedef long int (*L_fp)();
typedef int /* Unknown procedure type */ (*U_fp)();
typedef /* Subroutine */ int (*S_fp)();

static PyObject *ErrorObject;

static PyObject *ODRpackError()
{  
    if (! ErrorObject)
	ErrorObject = PyString_FromString("ODRpackError");
    Py_INCREF(ErrorObject);
    return ErrorObject;
}

static PyObject *ErrorReturn(char *mes)
{  
    if (!ErrorObject)
	ErrorObject = PyString_FromString("ODRpackError");
    PyErr_SetString(ErrorObject,mes);
    return NULL;
}

#define TRY(E) if( ! (E)) return NULL

static int dodr_CheckObject(PyObject *ob, int t, char *obname,
	char *tname, char *funname)
{	
    char buf[255];
    if (! PyArray_Check(ob))
	{	sprintf(buf,"Expected an array for parameter %s in dodr.%s",obname, funname);
        ErrorReturn(buf);
        return 0;
	}
    if (!(((PyArrayObject *)ob)->flags & CONTIGUOUS)) 
    {    
	sprintf(buf,"Parameter %s is not contiguous in dodr.%s",obname, funname);
	ErrorReturn(buf);
	return 0;
    }
    if (!(((PyArrayObject *)ob)->descr->type_num == t))
    {    
	sprintf(buf,"Parameter %s is not of type %s in dodr.%s",obname,tname, funname);
	ErrorReturn(buf);
        return 0;
    }
    return 1;
}

#define LDATA(p) ((long int *) (((PyArrayObject *)p)->data))
#define CHDATA(p) ((char *) (((PyArrayObject *)p)->data))
#define SHDATA(p) ((short int *) (((PyArrayObject *)p)->data))
#define DDATA(p) ((double *) (((PyArrayObject *)p)->data))
#define FDATA(p) ((float *) (((PyArrayObject *)p)->data))
#define CDATA(p) ((f2c_complex *) (((PyArrayObject *)p)->data))
#define ZDATA(p) ((f2c_doublecomplex *) (((PyArrayObject *)p)->data))

static PyObject *dodr_dodr(PyObject *self, PyObject *args)
{
    int  dodr_status__;
    PyObject *cbobject;
    U_fp fcn;
    long int n;
    long int m;
    long int np;
    long int nq;
    PyObject *beta;
    PyObject *y;
    long int ldy;
    PyObject *x;
    long int ldx;
    PyObject *we;
    long int ldwe;
    long int ld2we;
    PyObject *wd;
    long int ldwd;
    long int ld2wd;
    long int job;
    long int iprint;
    long int lunerr;
    long int lunrpt;
    PyObject *work;
    long int lwork;
    PyObject *iwork;
    long int liwork;
    long int info;
    
    TRY(PyArg_ParseTuple(args,"OiiiiOOiOiOiiOiiiiiiOiOii",&cbobject,&n,&m,&np,&nq,&beta,&y,&ldy,&x,&ldx,&we,&ldwe,&ld2we,&wd,&ldwd,&ld2wd,&job,&iprint,&lunerr,&lunrpt,&work,&lwork,&iwork,&liwork,&info));
    
    TRY(fcn = (U_fp)(callback_getCallbackFn(cbobject)));
    TRY(dodr_CheckObject(beta,PyArray_DOUBLE,"beta","PyArray_DOUBLE","dodr")); 
    TRY(dodr_CheckObject(y,PyArray_DOUBLE,"y","PyArray_DOUBLE","dodr")); 
    TRY(dodr_CheckObject(x,PyArray_DOUBLE,"x","PyArray_DOUBLE","dodr")); 
    TRY(dodr_CheckObject(we,PyArray_DOUBLE,"we","PyArray_DOUBLE","dodr")); 
    TRY(dodr_CheckObject(wd,PyArray_DOUBLE,"wd","PyArray_DOUBLE","dodr")); 
    TRY(dodr_CheckObject(work,PyArray_DOUBLE,"work","PyArray_DOUBLE","dodr")); 
    TRY(dodr_CheckObject(iwork,PyArray_LONG,"work","PyArray_LONG","dodr")); 
    
#if defined(NO_APPEND_FORTRAN)
    dodr_status__ = dodr(fcn,&n,&m,&np,&nq,DDATA(beta),DDATA(y),&ldy,DDATA(x),&ldx,DDATA(we),&ldwe,&ld2we,DDATA(wd),&ldwd,&ld2wd,&job,&iprint,&lunerr,&lunrpt,DDATA(work),&lwork,LDATA(iwork),&liwork,&info);
#else
    dodr_status__ = dodr_(fcn,&n,&m,&np,&nq,DDATA(beta),DDATA(y),&ldy,DDATA(x),&ldx,DDATA(we),&ldwe,&ld2we,DDATA(wd),&ldwd,&ld2wd,&job,&iprint,&lunerr,&lunrpt,DDATA(work),&lwork,LDATA(iwork),&liwork,&info);
#endif
    
    return Py_BuildValue("{s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i}","dodr_",dodr_status__,"n",n,"m",m,"np",np,"nq",nq,"ldy",ldy,"ldx",ldx,"ldwe",ldwe,"ld2we",ld2we,"ldwd",ldwd,"ld2wd",ld2wd,"job",job,"iprint",iprint,"lunerr",lunerr,"lunrpt",lunrpt,"lwork",lwork,"liwork",liwork,"info",info);
}


static struct PyMethodDef dodr_module_methods[] = {
    {"dodr",dodr_dodr,1},
    { NULL,NULL,0}
};

static PyObject *dodrError;

void initdodr()
{ 
    PyObject *m, *d;
    m = Py_InitModule("dodr",dodr_module_methods);
    import_array();
    import_callback();
    d = PyModule_GetDict(m);
    ErrorObject = ODRpackError();
    PyDict_SetItemString(d,"ODRpackError",ErrorObject);
}

