      SUBROUTINE GLOMTF (NPROB, N, X, FUNZ)
C
C     THE SUBROUTINE  GLOMTF  PROVIDES THE CODING OF 37 REAL-VALUED
C     FUNCTIONS OF  N  REAL VARIABLES, TO BE USED, TOGETHER WITH THE
C     SUBROUTINE  GLOMIP , TO DEFINE 37 TEST PROBLEMS FOR GLOBAL
C     MINIMIZATION SOFTWARE.
C
C     THE SUBROUTINE  GLOMTF  RETURNS IN  FUNZ  THE FUNCTION VALUE
C     AT THE POINT  X = (X1,X2,...,XN)  FOR THE FUNCTION DEFINED BY
C     PROBLEM NUMBER  NPROB .
C
C     CALLING STATEMENT
C
C        CALL GLOMTF (NPROB, N, X, FUNZ)
C
C     DESCRIPTION OF THE CALL PARAMETERS
C        (THE FORTRAN IMPLICIT TYPE DEFINITION FOR INTEGERS IS USED.
C        ALL NON-INTEGER PARAMETERS ARE DOUBLE-PRECISION).
C
C     NPROB   IS THE (INPUT) TEST-PROBLEM NUMBER
C
C     N   IS THE (INPUT) DIMENSION OF THE PROBLEM
C
C     X   IS AN (INPUT) N-VECTOR CONTAINING THE INDEPENDENT VARIABLES
C
C     FUNZ   IS THE (OUTPUT) VALUE AT  X  OF THE FUNCTION DEFINED BY
C        PROBLEM NUMBER  NPROB .
C
C
C
      DOUBLE PRECISION X
      DOUBLE PRECISION FUNZ
C
      DOUBLE PRECISION PI
      DOUBLE PRECISION P1A
      DOUBLE PRECISION P4A
      DOUBLE PRECISION P5A
      DOUBLE PRECISION P6A
      DOUBLE PRECISION P9A,P9B
      DOUBLE PRECISION P17A
      DOUBLE PRECISION P20A,P20B
      DOUBLE PRECISION P21A,P21B,P21C,P21D
      DOUBLE PRECISION P22A,P22B,P22C,P22D
      DOUBLE PRECISION P36A,P36B,P36C,P36D
      DOUBLE PRECISION P37A,P37B,P37C,P37D
      DOUBLE PRECISION Y
      DOUBLE PRECISION XX,DI,YY,BETA,S1,S2,A,B,R2,R4,R8,U,V,UU,VV,S
      DOUBLE PRECISION RG,RP,H,PUND,RANGE
      DOUBLE PRECISION FACT,VAR,PENFUN,RAN
C
      DIMENSION X(N)
C
      DIMENSION P20A(10,4),P20B(10)
      DIMENSION P21A(4,3),P21B(4,3),P21C(4)
      DIMENSION P22A(4,6),P22B(4,6),P22C(4)
      DIMENSION Y(10)
C
      DATA PI /3.14159265358979323846D0/
      DATA P1A /0.1D0/
      DATA P4A /0.1D0/
      DATA P5A /0.1D0/
      DATA P6A /0.1D0/
      DATA P9A,P9B /-1.4251284283197609708D0,-0.80032110047197312466D0/
      DATA P17A /1.275D0/
      DATA P20A /4.D0,1.D0,8.D0,6.D0,3.D0,2.D0,5.D0,8.D0,6.D0,7.D0,
     1           4.D0,1.D0,8.D0,6.D0,7.D0,9.D0,5.D0,1.D0,2.D0,3.6D0,
     2           4.D0,1.D0,8.D0,6.D0,3.D0,2.D0,3.D0,8.D0,6.D0,7.D0,
     3           4.D0,1.D0,8.D0,6.D0,7.D0,9.D0,3.D0,1.D0,2.D0,3.6D0/
      DATA P20B /0.1D0,0.2D0,0.2D0,0.4D0,0.4D0,0.6D0,0.3D0,0.7D0,
     1    0.5D0,0.5D0/
      DATA P21A /3.D0,0.1D0,3.D0,0.1D0,
     1          10.D0,10.D0,10.D0,10.D0,
     2          30.D0,35.D0,30.D0,35.D0/
      DATA P21B /0.3689D0,0.4699D0,0.1091D0,0.03815D0,
     1           0.1170D0,0.4387D0,0.8732D0,0.5743D0,
     2           0.2673D0,0.7470D0,0.5547D0,0.8828D0/
      DATA P21C /1.D0,1.2D0,3.D0,3.2D0/
      DATA P21D /-69.D0/
      DATA P22A /10.D0,0.05D0,3.D0,17.D0,3.D0,10.D0,3.5D0,8.D0,
     1           17.D0,17.D0,1.7D0,0.05D0,3.5D0,0.1D0,10.D0,10.D0,
     2           1.7D0,8.D0,17.D0,0.1D0,8.D0,14.D0,8.D0,14.D0/
      DATA P22B /0.1312D0,0.2329D0,0.2348D0,0.4047D0,
     1           0.1696D0,0.4135D0,0.1451D0,0.8828D0,
     2           0.5569D0,0.8307D0,0.3522D0,0.8732D0,
     3           0.0124D0,0.3736D0,0.2883D0,0.5743D0,
     4           0.8283D0,0.1004D0,0.3047D0,0.1091D0,
     5           0.5886D0,0.9991D0,0.6650D0,0.0381D0/
      DATA P22C /1.D0,1.2D0,3.D0,3.2D0/
      DATA P22D /-69.D0/
      DATA P36A,P36B,P36C,P36D /10.D1,1.D0,10.D0,0.98D0/
      DATA P37A,P37B,P37C,P37D /10.D0,1.D0,10.D0,0.98D0/
C
C     PENALIZATION FUNCTION
C
      PENFUN (VAR,RAN,FACT,IEXP) = FACT*(DABS(VAR)-RAN)**IEXP
C
      GO TO (10,20,30,40,50,60,70,80,90,100,110,120,130,140,150,
     1       160,170,180,190,200,210,220,230,240,250,260,270,280,
     2       290,300,310,320,330,340,350,360,370), NPROB
C
C    1  A FOURTH ORDER POLYNOMIAL  (N = 1)
C
   10 CONTINUE
      FUNZ = ((0.25D0*X(1)*X(1)-0.5D0)*X(1)+P1A)*X(1)
      RETURN
C
C    2  GOLDSTEIN SIXTH ORDER POLYNOMIAL  (N = 1)
C
   20 CONTINUE
      XX = X(1)*X(1)
      FUNZ = ((XX-15.D0)*XX+27.D0)*XX+250.D0
      RETURN
C
C    3  ONE-DIMENSIONAL PENALIZED SHUBERT FUNCTION  (N = 1)
C
   30 CONTINUE
      FUNZ = 0.D0
      DO 35 I = 1,5
         DI = DBLE(FLOAT(I))
         FUNZ = FUNZ+DI*DCOS((DI+1.D0)*X(1)+DI)
   35 CONTINUE
      IF (DABS(X(1)).GT.10.D0) FUNZ = FUNZ+PENFUN(X(1),10.D0,100.D0,2)
      RETURN
C
C    4  A FOURTH ORDER POLYNOMIAL IN TWO VARIABLES  (N = 2)
C
   40 CONTINUE
      XX = X(1)*X(1)
      YY = X(2)*X(2)
      FUNZ = 0.25D0*XX*XX-0.5D0*XX+P4A*X(1)+0.5D0*YY
      RETURN
C
C    5  A FUNCTION WITH A SINGLE ROW OF LOCAL MINIMA  (N = 2)
C
   50 CONTINUE
      FUNZ = 0.5D0*(P5A*X(1)*X(1)+1.D0-DCOS(2.D0*X(1)))+X(2)*X(2)
      RETURN
C
C    6  SIX-HUMP CAMEL FUNCTION  (N = 2)
C
   60 CONTINUE
      XX = X(1)*X(1)
      YY = X(2)*X(2)
      FUNZ = ((XX/3.D0-(2.D0+P6A))*XX+4.D0)*XX+X(1)*X(2)
     1    +4.D0*(YY-1.D0)*YY
      RETURN
C
C    7  TWO-DIMENSIONAL PENALIZED SHUBERT FUNCTION, BETA = 0  (N = 2)
C
   70 CONTINUE
      BETA = 0.D0
      GO TO 93
C
C    8  TWO-DIMENSIONAL PENALIZED SHUBERT FUNCTION, BETA = 1/2  (N = 2)
C
   80 CONTINUE
      BETA = 0.5D0
      GO TO 93
C
C    9  TWO-DIMENSIONAL PENALIZED SHUBERT FUNCTION, BETA = 1  (N = 2)
C
   90 CONTINUE
      BETA = 1.D0
C
   93 CONTINUE
      FUNZ = ((X(1)-P9A)**2+(X(2)-P9B)**2)*BETA
      S1 = 0.D0
      S2 = 0.D0
      DO 95 I = 1,5
         DI = DBLE(FLOAT(I))
         S1 = S1+DI*DCOS((DI+1.D0)*X(1)+DI)
         S2 = S2+DI*DCOS((DI+1.D0)*X(2)+DI)
   95 CONTINUE
      FUNZ = FUNZ+S1*S2
      IF (DABS(X(1)).GT.10.D0) FUNZ = FUNZ+PENFUN(X(1),10.D0,100.D0,2)
      IF (DABS(X(2)).GT.10.D0) FUNZ = FUNZ+PENFUN(X(2),10.D0,100.D0,2)
      RETURN
C
C   10  A FUNCTION WITH THREE ILL-CONDITIONED MINIMA, A=10  (N = 2)
C
  100 CONTINUE
      A = 1.D1
      B = 1.D-1
      GO TO 155
C
C   11  A FUNCTION WITH THREE ILL-CONDITIONED MINIMA, A=10**2  (N = 2)
C
  110 CONTINUE
      A = 1.D2
      B = 1.D-2
      GO TO 155
C
C   12  A FUNCTION WITH THREE ILL-CONDITIONED MINIMA, A=10**3  (N = 2)
C
  120 CONTINUE
      A = 1.D3
      B = 1.D-3
      GO TO 155
C
C   13  A FUNCTION WITH THREE ILL-CONDITIONED MINIMA, A=10**4  (N = 2)
C
  130 CONTINUE
      A = 1.D4
      B = 1.D-4
      GO TO 155
C
C   14  A FUNCTION WITH THREE ILL-CONDITIONED MINIMA, A=10**5  (N = 2)
C
  140 CONTINUE
      A = 1.D5
      B = 1.D-5
      GO TO 155
C
C   15  A FUNCTION WITH THREE ILL-CONDITIONED MINIMA, A=10**6  (N = 2)
C
  150 CONTINUE
      A = 1.D6
      B = 1.D-6
C
  155 CONTINUE
      XX = X(1)*X(1)
      YY = X(2)*X(2)
      R2 = XX+YY
      R4 = R2*R2
      R8 = R4*R4
      FUNZ = A*XX+YY-R4+B*R8
      RETURN
C
C   16  GOLDSTEIN-PRICE FUNCTION  (N = 2)
C
  160 CONTINUE
      U = X(1)+X(2)+1.D0
      V = 2.D0*X(1)-3.D0*X(2)
      UU = U*U
      VV = V*V
      FUNZ = (1.D0+UU*(36.D0-20.D0*U+3.D0*UU))
     1    * (30.D0+VV*(18.D0-16.D0*V+3.D0*VV))
      RETURN
C
C   17  PENALIZED BRANIN FUNCTION  (N = 2)
C
  170 CONTINUE
      FUNZ = (X(2)-P17A*(X(1)/PI)**2+(5.D0/PI)*X(1)-6.D0)**2
     1    +10.D0*(1.D0-1.D0/(8.D0*PI))*DCOS(X(1))+10.D0
      IF (DABS(X(1)-2.5D0).GT.7.5D0)
     1   FUNZ = FUNZ+PENFUN(X(1)-2.5D0,7.5D0,100.D0,2)
      IF (DABS(X(2)-7.5D0).GT.7.5D0)
     1   FUNZ = FUNZ+PENFUN(X(2)-7.5D0,7.5D0,100.D0,2)
      RETURN
C
C   18  PENALIZED SHEKEL FUNCTION, M = 5  (N = 4)
C
  180 CONTINUE
      M = 5
      GO TO 203
C
C   19  PENALIZED SHEKEL FUNCTION, M = 7  (N = 4)
C
  190 CONTINUE
      M = 7
      GO TO 203
C
C   20  PENALIZED SHEKEL FUNCTION, M = 10  (N = 4)
C
  200 CONTINUE
      M = 10
C
  203 CONTINUE
      FUNZ = 0.D0
      DO 207 I = 1,M
         S = P20B(I)
         DO 205 J = 1,N
            S = S+(X(J)-P20A(I,J))**2
  205    CONTINUE
         FUNZ = FUNZ - 1.D0/S
  207 CONTINUE
      DO 209 I = 1,N
         IF (DABS(X(I)-5.D0).GT.5.D0)
     1      FUNZ = FUNZ+PENFUN(X(I)-5.D0,5.D0,100.D0,2)
  209 CONTINUE
      RETURN
C
C   21  PENALIZED THREE-DIMENSIONAL HARTMAN FUNCTION  (N = 3)
C
  210 CONTINUE
      M = 4
      FUNZ = 0.D0
      DO 217 I = 1,M
         S = 0.D0
         DO 213 J = 1,N
            S = S-P21A(I,J)*(X(J)-P21B(I,J))**2
  213    CONTINUE
         IF (S.GE.P21D) FUNZ = FUNZ-P21C(I)*DEXP(S)
  217 CONTINUE
      GO TO 227
C
C   22  PENALIZED SIX-DIMENSIONAL HARTMAN FUNCTION  (N = 6)
C
  220 CONTINUE
      M = 4
      FUNZ = 0.D0
      DO 225 I = 1,M
         S = 0.D0
         DO 223 J = 1,N
            S = S-P22A(I,J)*(X(J)-P22B(I,J))**2
  223    CONTINUE
         IF (S.GE.P22D) FUNZ = FUNZ-P22C(I)*DEXP(S)
  225 CONTINUE
  227 CONTINUE
         DO 229 I = 1,N
         IF (DABS(X(I)-0.5D0).GT.0.5D0)
     1      FUNZ = FUNZ+PENFUN(X(I)-0.5D0,0.5D0,100.D0,2)
  229 CONTINUE
      RETURN
C
C   23  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 1  (N = 2)
C
  230 CONTINUE
C
C   24  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 1  (N = 3)
C
  240 CONTINUE
C
C   25  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 1  (N = 4)
C
  250 CONTINUE
      DO 255 I = 1,N
         Y(I) = 1.D0+0.25D0*(X(I)-1.D0)
  255 CONTINUE
      GO TO 285
C
C   26  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 2  (N = 5)
C
  260 CONTINUE
C
C   27  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 2  (N = 8)
C
  270 CONTINUE
C
C   28  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 2  (N = 10)
C
  280 CONTINUE
      DO 283 I = 1,N
         Y(I) = X(I)
  283 CONTINUE
C
  285 CONTINUE
      FUNZ = 10.D0*DSIN(PI*Y(1))**2+(Y(N)-1.D0)**2
      DO 287 I=2,N
         FUNZ = FUNZ+(Y(I-1)-1.D0)**2*(1.D0+10.D0*DSIN(PI*Y(I))**2)
  287 CONTINUE
      FUNZ = FUNZ*PI/DBLE(FLOAT(N))
      RANGE = 10.D0
      GO TO 347
C
C   29  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 3, RANGE = 10   (N = 2)
C
  290 CONTINUE
C
C   30  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 3, RANGE = 10   (N = 3)
C
  300 CONTINUE
C
C   31  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 3, RANGE = 10   (N = 4)
C
  310 CONTINUE
      RANGE = 10.D0
      GO TO 342
C
C   32  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 3, RANGE = 5   (N = 5)
C
  320 CONTINUE
C
C   33  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 3, RANGE = 5   (N = 6)
C
  330 CONTINUE
C
C   34  PENALIZED LEVY-MONTALVO FUNCTION, TYPE 3, RANGE = 5  (N = 7)
C
  340 CONTINUE
      RANGE = 5.D0
  342 CONTINUE
      FUNZ = DSIN(3.D0*PI*X(1))**2
     1   +(X(N)-1.D0)**2*(1.D0+DSIN(2.D0*PI*X(N))**2)
      DO 345 I=2,N
         FUNZ = FUNZ+(X(I-1)-1.D0)**2*(1.D0+DSIN(3.D0*PI*X(I))**2)
  345 CONTINUE
      FUNZ = FUNZ*0.1D0
  347 CONTINUE
      DO 349 I = 1,N
         IF (DABS(X(I)).GT.RANGE)
     1      FUNZ = FUNZ+PENFUN(X(I),RANGE,100.D0,4)
  349 CONTINUE
      RETURN
C
C   35  A FUNCTION WITH A SINGLE CUSP-SHAPED MINIMUM  (N = 5)
C
  350 CONTINUE
      FUNZ = 0.D0
      DO 355 I = 1,N
         FUNZ = FUNZ+DBLE(FLOAT(I))*X(I)*X(I)
  355 CONTINUE
      FUNZ = DSQRT(DSQRT(FUNZ))
      RETURN
C
C   36  A FUNCTION WITH A SMALL-ATTRACTION-REGION GLOBAL MINIMUM (N = 2)
C
  360 CONTINUE
      RG = P36A
      RP = P36B
      H = P36C
      PUND = P36D
      GOTO 373
C
C   37  A FUNCTION WITH A SMALL-ATTRACTION-REGION GLOBAL MINIMUM (N = 5)
C
  370 CONTINUE
      RG = P37A
      RP = P37B
      H = P37C
      PUND = P37D
  373 CONTINUE
      S = 0.D0
      DO 377 I = 2,N
         S = S+X(I)*X(I)
  377 CONTINUE
      FUNZ = S+X(1)*X(1)
      S = S+(X(1)-RG)**2
      IF (S.LT.RP*RP*PUND) FUNZ = FUNZ-(RG*RG+H)*DEXP(-S/(RP*RP-S))
      RETURN
C
      END
