      SUBROUTINE SIGMA1(N,X0,NSUC,IPRINT,XMIN,FMIN,NFEV,IOUT)
C
C  SIGMA1  IS A 'DRIVER' SUBROUTINE WHICH SIMPLY CALLS THE PRINCIPAL
C  SUBROUTINE  SIGMA  AFTER HAVING ASSIGNED DEFAULT VALUES TO A NUMBER
C  OF INPUT PARAMETERS OF  SIGMA , AND HAS THEREFORE A CONSIDERABLY
C  LOWER NUMBER OF INPUT PARAMETERS.
C  IT CAN BE USED AS A SIMPLE EXAMPLE OF HOW TO CALL  SIGMA , BUT
C  ALSO AS AN EASY-TO-USE DRIVER FOR THE AVERAGE USER, WHICH MAY FIND
C  IT EASIER TO CALL  SIGMA1  INSTEAD OF  SIGMA , THUS AVOIDING THE
C  TROUBLE OF ASSIGNING A VALUE TO ALL THE INPUT PARAMETERS OS  SIGMA .
C  ALL THE PARAMETERS IN THE DEFINITION OF  SIGMA1  HAVE THE SAME MEA-
C  NING AS IN  SIGMA .
C
C  THE USER OF  SIGMA1  MUST ONLY GIVE VALUES TO THE INPUT PARAMETERS
C      N, X0, NSUC, IPRINT
C  AND OBTAINS ON OUTPUT THE SAME OUTPUT PARAMETERS OF  SIGMA
C      XMIN, FMIN, NFEV, IOUT
C
C  WE RECALL HERE THE MEANING OF THE ABOVE PARAMETERS
C
C  N       IS THE PROBLEM DIMENSION (NUMBER OF VARIABLES)
C  X0      IS AN  N-VECTOR CONTAINING THE INITIAL VALUES OF THE
C          X-VARIABLES
C  NSUC    IS THE REQUESTED NUMBER OF SUCCESSFUL TRIALS
C          AFTER WHICH THE COMPUTATION IS STOPPED.
C  IPRINT  IS AN INDEX USED TO CONTROL THE AMOUNT OF PRINTED OUTPUT
C          BY CONTROLLING THE CALLS TO THE USER-SUPPLIED OUTPUT SUB-
C          ROUTINES  PTSEG  (END-OF-SEGMENT OUTPUT),  PTRIAL  (END-
C          OF-TRIAL OUTPUT), AND  PTKSUC (END-OF-TRIAL OUTPUT RELATED
C          TO THE COUNT OF SUCCESSFUL TRIALS), WHICH ARE DESCRIBED
C          BELOW.
C          IPRINT.LT.0   NO CALL TO THE OUTPUT SUBROUTINES
C          IPRINT.EQ.0   CALL ONLY  PTRIAL  AND  PTKSUC
C          IPRINT.GT.0   CALL ALL OUTPUT SUBROUTINES.
C  XMIN    IS AN N-VECTOR CONTAINING THE COORDINATES OF THE POINT
C          (OR POSSIBLY ONE OF THE POINTS) WHERE THE FINAL VALUE  FMIN
C          OF  FOPT  WAS FOUND.
C  FMIN    IS THE FINAL VALUE OF THE BEST CURRENT MINIMUM FUNCTION
C          VALUE  FOPT.
C  NFEV    IS THE TOTAL NUMBER OF FUNCTION EVALUATION (INCLUDING
C          THOSE USED FOR THE COMPUTATION OF DERIVATIVES, AND FOR
C          THE REJECTED TIME-INTEGRATION STEPS).
C  IOUT    IS THE INDICATOR OF THE STOPPING CONDITIONS, AS FOLLOWS
C          IF  IOUT = -99  A FATAL ERROR WAS DETECTED WHEN PERFOR-
C             MING SOME PRELIMINARY CHECKING OF THE INPUT DATA, AND
C             THE ALGORITHM WAS NOT EVEN STARTED
C          OTHERWISE THE ALGORITHM WAS STARTED, AND THE MEANING OF
C          IOUT  IS AS FOLLOWS
C          IF  IOUT.EQ.0  NO TRIAL HAD A UNIFORM STOP.
C          IF  IOUT.NE.0  THE SIGN AND THE MAGNITUDE OF  IOUT  HAVE
C          THE FOLLOWING MEANING
C          A) THE SIGN OF  IOUT  INDICATES IF THE BEST UNIFORM STOP
C          (I.E. THE ONE IN WHICH  FTFOPT  WAS OBTAINED)
C          IS TO BE CONSIDERED SUCCESSFUL (IOUT.GT.0) OR UNSUCCESSFUL
C          B) THE MAGNITUDE OF  IOUT  INDICATES WHICH ONE OF THE
C          NUMERICAL EQUALITY CRITERIA WAS SATISFIED IN THE BEST
C          UNIFORM STOP
C          IABS(IOUT).EQ.1  RELATIVE DIFFERENCE CRITERION
C          IABS(IOUT).EQ.2  ABSOLUTE DIFFERENCE CRITERION
C          IABS(IOUT).EQ.3  BOTH CRITERIA
C          (IOUT  IS THE FINAL VALUE OF THE INTERNAL PARAMETER  ISTOPT
C          (AN OUTPUT INDICATOR OF THE USER-SUPPLIED SUBROUTINE
C          PTRIAL )).
C          SUCCESS IS CLAIMED BY THE ALGORITHM IF  IOUT .GT. 0,
C          I.E. IF AT LEAST ONE OF THE TRIALS STOPPED SUCCESSFULLY
C          (I.E. WITH A POSITIVE VALUE OF THE TRIAL STOP INDICATOR
C          ISTOP ), AND THE SUCCESSFUL TRIALS (AS COUNTED BY  KSUC )
C          ARE CURRENTLY VALID.
C
      DOUBLE PRECISION X0,XMIN,FMIN
      DOUBLE PRECISION DX,EPS,H,TOLABS,TOLREL
      DOUBLE PRECISION VRMAX,VRMIN,XRMAX,XRMIN
      DIMENSION X0(N),XMIN(N)
      DIMENSION XRMIN(100),XRMAX(100)
      DATA VRMIN,VRMAX /-1.D4,1.D4/
      DATA NTRILD/50/
C
      H = 1.D-10
      EPS = 1.D0
      DX = 1.D-9
      IRAND = 0
      NTRAJ = 0
      ISEGBR = 0
      INKPBR = 0
      KPBR0 = 0
      NPMIN = 10
      NPMAX0 = 100
      INPMAX = 50
      NTRIAL = MAX0(NTRILD,5*NSUC)
      TOLREL = 1.D-3
      TOLABS = 1.D-6
      KPASCA = 10
      IF(N.GT.5)KPASCA = 300
      INHP = 1
      DO 1 IX = 1,N
         XRMIN(IX)=VRMIN
         XRMAX(IX)=VRMAX
 1    CONTINUE
C
      CALL SIGMA ( N, X0, H, EPS, DX,
     1             NTRAJ, ISEGBR, KPBR0, INKPBR,
     2             NPMIN, NPMAX0, INPMAX,
     3             NSUC, NTRIAL, TOLREL, TOLABS, XRMIN, XRMAX,
     4             KPASCA, IRAND, INHP, IPRINT,
     5             XMIN, FMIN, NFEV, IOUT )
C
      RETURN
      END
